%define DOCSTRING
"pyAgrum is a Python wrapper for the C++ aGrUM library. It provides a high-level
interface to the part of agrum allowing to create, handle and make computations
into Bayesian Networks. The module is mainly generated by the SWIG
interface generator."
%enddef
%module(docstring=DOCSTRING, directors="1") pyAgrum
%feature("autodoc", "0");
%include "docs.i"

//317 : Specialization of non-template
//320 : Explicit template instantiation ignored.
//325 : Nested class not currently supported (Database ignored)
#pragma SWIG nowarn=320,317,325

//#pragma SWIG nowarn=341,342 // The 'using' keyword in type aliasing is not fully supported yet.


%begin %{
#include <cmath>
%}

%include "std_vector.i"
%include "std_string.i"

%{
#define SWIG_FILE_WITH_INIT

#include "extensions/helpers.h"
%}

%pythoncode %{
  import numpy
%}

//////////////////////////////////////////////////////////////////
/* declaration of code modifiers for 'pythonification' of aGrUM */
//////////////////////////////////////////////////////////////////
%include "exceptions.i"
%include "pythonize.i"



//////////////////////////////////////////////////////////////////
/* declaration of code enhancers for pyAgrum */
//////////////////////////////////////////////////////////////////
%include "core.i"
%include "variables.i"
%include "instantiation.i"

%include "potential.i"

%include "graphs.i"

%include "pylisteners.i"

%include "bayesnet.i"
%include "inference.i"
%include "learning.i"
%include "kl.i"

%include "credalnet.i"

%include "influenceDiagram.i"
%include "influenceDiagramInference.i"

%include "prm.i"


//////////////////////////////////////////////////////////////////
/* extraction of the API for all wrappers */
//////////////////////////////////////////////////////////////////
%include "aGrUM_wrap.i"

%pythoncode %{
Potential = Potential_double

randomDistribution = randomDistribution_double

SimpleBayesNet = IBayesNet_double
BayesNet = BayesNet_double

LazyPropagation = LazyPropagation_double
ShaferShenoyInference = ShaferShenoyInference_double
VariableElimination = VariableElimination_double

GibbsSampling = GibbsSampling_double
ImportanceSampling=ImportanceSampling_double
WeightedSampling=WeightedSampling_double
MonteCarloSampling=MonteCarloSampling_double
LoopyImportanceSampling=LoopyImportanceSampling_double
LoopyGibbsSampling=LoopyGibbsSampling_double
LoopyWeightedSampling=LoopyWeightedSampling_double
LoopyMonteCarloSampling=LoopyMonteCarloSampling_double

LoopyBeliefPropagation = LoopyBeliefPropagation_double

BruteForceKL = BruteForceKL_double
GibbsKL = GibbsKL_double

CredalNet = CredalNet_double
CNMonteCarloSampling = CNMonteCarloSampling_double
CNLoopyPropagation = CNLoopyPropagation_double

DiscretizedVariable = DiscretizedVariable_double

InfluenceDiagram = InfluenceDiagram_double
InfluenceDiagramInference = InfluenceDiagramInference_double

BNLearner =  BNLearner_double
BNDatabaseGenerator = BNDatabaseGenerator_double
%}

 // Explicit template instantiation ignored.
